@@ -514,13 +514,10 @@ QString AgentBase::parseArguments( int argc, char **argv )
     kDebug() << "Identifier argument missing";
     exit( 1 );
   }
-
-  QByteArray catalog;
-  char *p = strrchr( argv[0], '/' );
-  if ( p )
-    catalog = QByteArray( p + 1 );
-  else
-    catalog = QByteArray( argv[0] );
+ 
+  const QFileInfo fi( QString::fromLocal8Bit( argv[0] ) );
+  // strip off full path and possible .exe suffix
+  const QByteArray catalog = fi.baseName().toLatin1();
 
   KCmdLineArgs::init( argc, argv, identifier.toLatin1(), catalog, ki18n( "Akonadi Agent" ), "0.1",
                       ki18n( "Akonadi Agent" ) );
