@@ -42,7 +42,7 @@ class KDescendantsProxyModelPrivate
       m_ignoreNextLayoutChanged(false),
       m_relayouting(false),
       m_displayAncestorData( false ),
-      m_ancestorSeparator( QLatin1String( " / " ) )
+      m_ancestorSeparator( QLatin1Char( '/' ) )
   {
   }
 
@@ -125,7 +125,7 @@ void KDescendantsProxyModelPrivate::processPendingParents()
   const QVector<QPersistentModelIndex>::iterator begin = m_pendingParents.begin();
   QVector<QPersistentModelIndex>::iterator it = begin;
 
-  // Process chunkSize elements per invokation.
+  // Process chunkSize elements per invocation.
   static const int chunkSize = 30;
 
   const QVector<QPersistentModelIndex>::iterator end =
@@ -188,8 +188,8 @@ void KDescendantsProxyModelPrivate::updateInternalIndexes(int start, int offset)
   // TODO: Make KHash2Map support key updates and do this backwards.
   QHash<int, QPersistentModelIndex> updates;
   {
-    Mapping::right_const_iterator it = const_cast<const Mapping&>(m_mapping).rightLowerBound(start);
-    const Mapping::right_const_iterator end = m_mapping.rightConstEnd();
+    Mapping::right_iterator it = m_mapping.rightLowerBound(start);
+    const Mapping::right_iterator end = m_mapping.rightEnd();
 
     while (it != end)
     {
