@@ -28,6 +28,7 @@
 #include <akonadi/agentbase.h>
 #include <akonadi/collection.h>
 #include <akonadi/item.h>
+#include <akonadi/itemsync.h>
 
 class KJob;
 class Akonadi__ResourceAdaptor;
@@ -101,10 +102,11 @@ class ResourceBasePrivate;
  * - itemAdded()
  * - itemChanged()
  * - itemRemoved()
+ *
  * Note that these three functions don't get the full payload of the items by default,
  * you need to change the item fetch scope of the change recorder to fetch the full
  * payload. This can be expensive with big payloads, though.<br>
- * Once you have handled changes in these methods call changeCommitted().
+ * Once you have handled changes in these methods, call changeCommitted().
  * These methods are called whenever a local item related to this resource is
  * added, modified or deleted. They are only called if the resource is online, otherwise
  * all changes are recorded and replayed as soon the resource is online again.
@@ -209,6 +211,14 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     void synchronized();
 
+    /**
+     * Emitted when a collection attributes synchronization has been completed.
+     *
+     * @param collectionId The identifier of the collection whose attributes got synchronized.
+     * @since 4.6
+     */
+    void attributesSynchronized( qlonglong collectionId );
+
   protected Q_SLOTS:
     /**
      * Retrieve the collection tree from the remote server and supply it via
@@ -217,6 +227,20 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     virtual void retrieveCollections() = 0;
 
+    /**
+     * Retrieve the attributes of a single collection from the backend. The
+     * collection to retrieve attributes for is provided as @p collection.
+     * Add the attributes parts and call collectionAttributesRetrieved()
+     * when done.
+     *
+     * @param collection The collection whose attributes should be retrieved.
+     * @see collectionAttributesRetrieved()
+     * @since 4.6
+     */
+    // KDE5: Make it pure virtual, for now can be called only by invokeMethod()
+    //       in order to simulate polymorphism
+    void retrieveCollectionAttributes( const Akonadi::Collection &collection );
+
     /**
      * Retrieve all (new/changed) items in collection @p collection.
      * It is recommended to use incremental retrieval if the backend supports that
@@ -243,6 +267,15 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     virtual bool retrieveItem( const Akonadi::Item &item, const QSet<QByteArray> &parts ) = 0;
 
+    /**
+     * Abort any activity in progress in the backend. By default this method does nothing.
+     *
+     * @since 4.6
+     */
+    // KDE5: Make it pure virtual, for now can be called only by invokeMethod()
+    //       in order to simulate polymorphism
+    void abortActivity();
+
   protected:
     /**
      * Creates a base resource.
@@ -263,6 +296,14 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     void itemRetrieved( const Item &item );
 
+    /**
+     * Call this method from retrieveCollectionAttributes() once the result is available.
+     *
+     * @param item The collection whose attributes got retrieved.
+     * @since 4.6
+     */
+    void collectionAttributesRetrieved( const Collection &collection );
+
     /**
      * Resets the dirty flag of the given item and updates the remote id.
      *
@@ -346,6 +387,26 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     void setItemStreamingEnabled( bool enable );
 
+    /**
+     * Set transaction mode for item sync'ing.
+     * @see Akonadi::ItemSync::TransactionMode
+     * @since 4.6
+     */
+    void setItemTransactionMode( ItemSync::TransactionMode mode );
+
+    /**
+     * Set the fetch scope applied for item synchronization.
+     * By default, the one set on the changeRecorder() is used. However, it can make sense
+     * to specify a specialized fetch scope for synchronization to improve performance.
+     * The rule of thumb is to remove anything from this fetch scope that does not provide
+     * additional information regarding whether and item has changed or not. This is primarily
+     * relevant for backends not supporting incremental retrieval.
+     * @param fetchScope The fetch scope to use by the internal Akonadi::ItemSync instance.
+     * @see Akonadi::ItemSync
+     * @since 4.6
+     */
+    void setItemSynchronizationFetchScope( const ItemFetchScope &fetchScope );
+
     /**
      * Call this method to supply incrementally retrieved items from the remote server.
      *
@@ -398,6 +459,22 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     void synchronizeCollection( qint64 id );
 
+    /**
+     * This method is called whenever the collection with the given @p id
+     * shall be synchronized.
+     * @param recursive if true, a recursive syncronization is done
+     */
+    void synchronizeCollection( qint64 id, bool recursive );
+
+    /**
+     * This method is called whenever the collection with the given @p id
+     * shall have its attributes synchronized.
+     *
+     * @param id The id of the collection to synchronize
+     * @since 4.6
+     */
+    void synchronizeCollectionAttributes( qint64 id );
+
     /**
      * Refetches the Collections.
      */
@@ -418,6 +495,12 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      * Stops the execution of the current task and continues with the next one.
      * The current task will be tried again later.
      *
+     * This can be used to delay the task processing until the resource has reached a safe
+     * state, e.g. login to a server succeeded.
+     *
+     * @note This does not change the order of tasks so if there is no task with higher priority
+     *       e.g. a custom task added with #Prepend the deferred task will be processed again.
+     *
      * @since 4.3
      */
     void deferTask();
@@ -440,6 +523,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
     void setHierarchicalRemoteIdentifiersEnabled( bool enable );
 
     friend class ResourceScheduler;
+    friend class ResourceState;
 
     /**
      * Describes the scheduling priority of a task that has been queued
@@ -449,9 +533,9 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      * @since 4.4
      */
     enum SchedulePriority {
-      Prepend,            ///> The task will be executed as soon as the current task has finished.
-      AfterChangeReplay,  ///> The task is scheduled after the last ChangeReplay task in the queue
-      Append              ///> The task will be executed after all tasks currently in the queue are finished
+      Prepend,            ///< The task will be executed as soon as the current task has finished.
+      AfterChangeReplay,  ///< The task is scheduled after the last ChangeReplay task in the queue
+      Append              ///< The task will be executed after all tasks currently in the queue are finished
     };
 
     /**
@@ -491,6 +575,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
   private:
     Q_DECLARE_PRIVATE( ResourceBase )
 
+    Q_PRIVATE_SLOT( d_func(), void slotAbortRequested() )
     Q_PRIVATE_SLOT( d_func(), void slotDeliveryDone( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void slotCollectionSyncDone( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void slotDeleteResourceCollection() )
@@ -499,11 +584,16 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
     Q_PRIVATE_SLOT( d_func(), void slotLocalListDone( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void slotSynchronizeCollection( const Akonadi::Collection& ) )
     Q_PRIVATE_SLOT( d_func(), void slotCollectionListDone( KJob* ) )
+    Q_PRIVATE_SLOT( d_func(), void slotSynchronizeCollectionAttributes( const Akonadi::Collection& ) )
+    Q_PRIVATE_SLOT( d_func(), void slotCollectionListForAttributesDone( KJob* ) )
+    Q_PRIVATE_SLOT( d_func(), void slotCollectionAttributesSyncDone( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void slotItemSyncDone( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void slotPercent( KJob*, unsigned long ) )
+    Q_PRIVATE_SLOT( d_func(), void slotDelayedEmitProgress() )
     Q_PRIVATE_SLOT( d_func(), void slotPrepareItemRetrieval( const Akonadi::Item& item ) )
     Q_PRIVATE_SLOT( d_func(), void slotPrepareItemRetrievalResult( KJob* ) )
     Q_PRIVATE_SLOT( d_func(), void changeCommittedResult( KJob* ) )
+    Q_PRIVATE_SLOT( d_func(), void slotSessionReconnected() )
 };
 
 }
