@@ -2,7 +2,7 @@
   This file is part of the kblog library.
 
   Copyright (c) 2006-2007 Christian Weilbach <christian_weilbach@web.de>
-  Copyright (c) 2007 Mike Arthur <mike@mikearthur.co.uk>
+  Copyright (c) 2007 Mike McQuaid <mike@mikemcquaid.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -41,6 +41,8 @@ BlogPost::BlogPost( const KBlog::BlogPost &post )
   d_ptr->mPostId = post.postId();
   d_ptr->mTitle = post.title();
   d_ptr->mContent = post.content();
+  d_ptr->mAdditionalContent = post.additionalContent();
+  d_ptr->mWpSlug = post.slug();
   d_ptr->mCategories = post.categories();
   d_ptr->mTags = post.tags();
   d_ptr->mMood = post.mood();
@@ -75,10 +77,9 @@ BlogPost::BlogPost( const KCal::Journal &journal )
   d_ptr->mJournalId = journal.uid();
   d_ptr->mStatus = New;
   d_ptr->mTitle = journal.summary();
-  if (journal.descriptionIsRich()) {
-    d_ptr->mContent = d_ptr->cleanRichText(journal.description());
-  }
-  else {
+  if ( journal.descriptionIsRich() ) {
+    d_ptr->mContent = d_ptr->cleanRichText( journal.description() );
+  } else {
     d_ptr->mContent = journal.description();
   }
   d_ptr->mCategories = journal.categories();
@@ -182,6 +183,26 @@ void BlogPost::setContent( const QString &content )
 //   //TODO
 // }
 
+QString BlogPost::additionalContent() const
+{
+    return d_ptr->mAdditionalContent;
+}
+
+void BlogPost::setAdditionalContent( const QString &additionalContent )
+{
+  d_ptr->mAdditionalContent = additionalContent;
+}
+
+QString BlogPost::slug() const
+{
+    return d_ptr->mWpSlug;
+}
+
+void BlogPost::setSlug( const QString &slug )
+{
+    d_ptr->mWpSlug = slug;
+}
+
 KUrl BlogPost::link() const
 {
   return d_ptr->mLink;
@@ -333,20 +354,19 @@ BlogPost &BlogPost::operator=( const BlogPost &other )
 
 QString BlogPostPrivate::cleanRichText( QString richText ) const
 {
-  QRegExp getBodyContents("<body[^>]*>(.*)</body>");
-  if ( getBodyContents.indexIn( richText ) )
-  {
+  QRegExp getBodyContents( "<body[^>]*>(.*)</body>" );
+  if ( getBodyContents.indexIn( richText ) ) {
     // Get anything inside but excluding the body tags
-    richText = getBodyContents.cap(1);
+    richText = getBodyContents.cap( 1 );
     // Get rid of any whitespace
-    richText.replace(QRegExp("^\\s+"),"");
+    richText.remove( QRegExp( "^\\s+" ) );
   }
   // Get rid of styled paragraphs
-  richText.replace(QRegExp("<p style=\"[^\"]*\">"),"<p>");
+  richText.replace( QRegExp( "<p style=\"[^\"]*\">" ), "<p>" );
 
   // If we're left with empty content then return a clean empty string
   if ( richText == "<p></p>" ) {
-    richText = QString();
+    richText.clear();
   }
 
   return richText;
