@@ -53,9 +53,6 @@ namespace KIMAP
       QList<MailBoxDescriptor> namespaces;
       QByteArray command;
 
-      QList<MailBoxDescriptor> descriptors;
-      QMap< MailBoxDescriptor, QList<QByteArray> > flags;
-
       QTimer emitPendingsTimer;
       QList<MailBoxDescriptor> pendingDescriptors;
       QList< QList<QByteArray> > pendingFlags;
@@ -102,14 +99,12 @@ QList<MailBoxDescriptor> ListJob::queriedNamespaces() const
 
 QList<MailBoxDescriptor> ListJob::mailBoxes() const
 {
-  Q_D(const ListJob);
-  return d->descriptors;
+  return QList<MailBoxDescriptor>();
 }
 
 QMap< MailBoxDescriptor, QList<QByteArray> > ListJob::flags() const
 {
-  Q_D(const ListJob);
-  return d->flags;
+  return QMap< MailBoxDescriptor, QList<QByteArray> >();
 }
 
 void ListJob::doStart()
@@ -155,15 +150,20 @@ void ListJob::handleResponse( const Message &response )
     d->emitPendings();
   }
 
-  if (handleErrorReplies(response) == NotHandled) {
-    if ( response.content.size() >= 5
-           && response.content[1].toString()==d->command ) {
+  if ( handleErrorReplies( response ) == NotHandled ) {
+    if ( response.content.size() >= 5 && response.content[1].toString() == d->command ) {
       QList<QByteArray> flags = response.content[2].toList();
       QByteArray separator = response.content[3].toString();
+      if ( separator.isEmpty() ) {
+        // Defaults to / for servers reporting an empty list
+        // it's supposedly not a problem as servers doing that
+        // only do it for mailboxes with no child.
+        separator = "/";
+      }
       Q_ASSERT(separator.size()==1);
       QByteArray fullName;
       for ( int i=4; i<response.content.size(); i++ ) {
-        fullName+= response.content[i].toString()+' ';
+        fullName += response.content[i].toString() + ' ';
       }
       fullName.chop( 1 );
 
@@ -173,9 +173,6 @@ void ListJob::handleResponse( const Message &response )
       mailBoxDescriptor.separator = QChar( separator[0] );
       mailBoxDescriptor.name = QString::fromUtf8( fullName );
 
-      d->descriptors << mailBoxDescriptor;
-      d->flags[mailBoxDescriptor] = flags;
-
       d->pendingDescriptors << mailBoxDescriptor;
       d->pendingFlags << flags;
     }
